@@ -233,7 +233,7 @@ KGpgCaffPrivate::slotSigningFinished(int result)
 			int index = 1;
 			removeMode = KGpgDelUid::RemoveAllOther;
 
-			while ( (otherUid = key->getUid(index++)) != NULL) {
+			while ( (otherUid = key->getUid(index++)) != Q_NULLPTR) {
 				if (otherUid == uid) {
 					removeMode = KGpgDelUid::RemoveWithEmail;
 					break;
@@ -302,7 +302,7 @@ KGpgCaffPrivate::slotExportFinished(int result)
 	const KGpgKeyNode *key = uid->getKeyNode();
 
 	KGpgExport *exp = qobject_cast<KGpgExport *>(sender());
-	Q_ASSERT(exp != NULL);
+	Q_ASSERT(exp != Q_NULLPTR);
 
 	QString body = KGpgSettings::emailTemplate();
 	body.replace(QLatin1Char( '%' ) + i18nc("Email template placeholder for key id", "KEYID") + QLatin1Char( '%' ), key->getId());
@@ -329,7 +329,7 @@ KGpgCaffPrivate::slotTextEncrypted(int result)
 	switch (result) {
 	case KGpgTransaction::TS_OK: {
 		KGpgEncrypt *enc = qobject_cast<KGpgEncrypt *>(sender());
-		Q_ASSERT(enc != NULL);
+		Q_ASSERT(enc != Q_NULLPTR);
 
 		const QString text = enc->encryptedText().join(QLatin1String("\n"));
 
